# Table of Conents:


* [GF Latin Kernel :warning:](#gf-latin-kernel)
* [GF Latin Core](#gf-latin-core)
* [GF Latin African](#gf-latin-african)
* [GF Arabic Core](#gf-arabic-core)
* [GF Arabic Plus](#gf-arabic-plus)

> [!NOTE]  
> This document is a human-readable representation of the glyphset defintions defined in code [here](/Lib/glyphsets/definitions/__init__.py) and gets updated automatically as part of the `sh build.sh` command.



## GF Latin Kernel

GF_Latin_Kernel is **statically** defined as:

* Script: Latin
* Codepoints defined in [GF_Latin_Kernel.stub.nam](/GF_glyphsets/Latin/definitions/GF_Latin_Kernel.stub.nam)

> [!WARNING]  
> Since this glyphset has no defined languages, it can't be checked via Fontbakery's `shape_languages` check. Please add language code definions here.

The resulting glyphset can be found here: [GF_Latin_Kernel.nam](/Lib/glyphsets/definitions/nam/GF_Latin_Kernel.nam)


## GF Latin Core

GF_Latin_Core is **statically** defined as:

* Script: Latin
* Codepoints defined in [GF_Latin_Core.stub.nam](/GF_glyphsets/Latin/definitions/GF_Latin_Core.stub.nam)
* Unencoded glyphs defined in [GF_Latin_Core.stub.glyphs](/GF_glyphsets/Latin/definitions/GF_Latin_Core.stub.glyphs)
* List of languages: `Albanian (sq_Latn), Catalan (ca_Latn), Croatian (hr_Latn), Czech (cs_Latn), Danish (da_Latn), Dutch (nl_Latn), English (en_Latn), Finnish (fi_Latn), French (fr_Latn), German (de_Latn), Hungarian (hu_Latn), Icelandic (is_Latn), Italian (it_Latn), Latvian (lv_Latn), Lithuanian (lt_Latn), Maltese (mt_Latn), Norwegian Bokmål (nb_Latn), Polish (pl_Latn), Portuguese (pt_Latn), Romanian (ro_Latn), Serbian (Latin) (sr_Latn), Slovak (sk_Latn), Spanish (es_Latn), Swedish (sv_Latn), Turkish (tr_Latn), Welsh (cy_Latn)`

The resulting glyphset can be found here: [GF_Latin_Core.nam](/Lib/glyphsets/definitions/nam/GF_Latin_Core.nam)


## GF Latin African

GF_Latin_African is **dynamically** defined as:

* Script: Latin
* All languages of the countries `Algeria (DZ), Angola (AO), Benin (BJ), Botswana (BW), British Indian Ocean Territory (IO), Burkina Faso (BF), Burundi (BI), Cameroon (CM), Canary Islands (IC), Cape Verde (CV), Central African Republic (CF), Ceuta & Melilla (EA), Chad (TD), Comoros (KM), Congo - Brazzaville (CG), Congo - Kinshasa (CD), Côte d’Ivoire (CI), Djibouti (DJ), Egypt (EG), Equatorial Guinea (GQ), Eritrea (ER), Eswatini (SZ), Ethiopia (ET), French Southern Territories (TF), Gabon (GA), Gambia (GM), Ghana (GH), Guinea (GN), Guinea-Bissau (GW), Kenya (KE), Lesotho (LS), Liberia (LR), Libya (LY), Madagascar (MG), Malawi (MW), Mali (ML), Mauritania (MR), Mauritius (MU), Mayotte (YT), Morocco (MA), Mozambique (MZ), Namibia (NA), Niger (NE), Nigeria (NG), Rwanda (RW), Réunion (RE), Senegal (SN), Seychelles (SC), Sierra Leone (SL), Somalia (SO), South Africa (ZA), South Sudan (SS), St. Helena (SH), Sudan (SD), São Tomé & Príncipe (ST), Tanzania (TZ), Togo (TG), Tunisia (TN), Uganda (UG), Western Sahara (EH), Zambia (ZM), Zimbabwe (ZW)`
* With a population of over 1 speakers
* Including auxiliary characters


The following list of languages is computed as a result of the dynamic conditions described above:

`Abidji (abi_Latn), Abron (abr_Latn), Abua (abn_Latn), Acoli (ach_Latn), Adangme (ada_Latn), Adara (kad_Latn), Adele (ade_Latn), Adioukrou (adj_Latn), Afar (aa_Latn), Afrikaans (af_Latn), Agatu (agc_Latn), Aghem (agq_Latn), Agwagwune (yay_Latn), Ahanta (aha_Latn), Aja (ajg_Latn), Akebu (keu_Latn), Akoose (bss_Latn), Akuapem Twi (tw_akuapem_Latn), Alago (ala_Latn), Amo (amo_Latn), Anaang (anw_Latn), Anii (blo_Latn), Anufo (cko_Latn), Anyin (any_Latn), Arabic, Chadian Spoken (shu_Latn), Ashe (ahs_Latn), Asu (asa_Latn), Atsam (cch_Latn), Avatime (avn_Latn), Avokaya (avu_Latn), Awak (awo_Latn), Awing (azo_Latn), Ayizo Gbe (ayb_Latn), Baatonum (bba_Latn), Bacama (bcy_Latn), Bafia (ksf_Latn), Bafut (bfd_Latn), Baga Sitemu (bsp_Latn), Baka (bdh_Latn), Baka (beh_Latn), Baka (bkc_Latn), Balanta-Ganja (bjt_Latn), Bali (bcn_Latn), Bambara (bm_Latn), Bamun, Latin (bax_Latn), Bana (bcw_Latn), Banda, West Central (bbp_Latn), Bandi (bza_Latn), Bandial (bqj_Latn), Bangwinji (bsj_Latn), Baoulé (bci_Latn), Bapuku (bnm_Latn), Bari (bfa_Latn), Basa (bzw_Latn), Basaa (bas_Latn), Bassa (bsq_Latn), Bassari (bsc_Latn), Bassari (bsc_Latn_GN), Bedawiyet (bej_Latn), Bedjond (bjv_Latn), Bekwarra (bkv_Latn), Belanda Viri, Latin (bvi_Latn), Bemba (bem_Latn), Bena (bez_Latn), Bench (bcq_Latn), Beng (nhb_Latn), Benga (bng_Latn), Berom (bom_Latn), Bete-Bendi (btt_Latn), Bhele (bhy_Latn), Bilen (byn_Latn), Bimoba (bim_Latn), Bini (bin_Latn), Birifor, Southern (biv_Latn), Bissa (bib_Latn), Bisã (bqp_Latn), Boko (bqc_Latn), Bokobaru (bus_Latn), Bomu (bmq_Latn), Bondoukou Kulango (kzc_Latn), Bozo, Hainyaxo (bzx_Latn), Buamu (box_Latn), Bube (bvb_Latn), Budu (buu_Latn), Bulu (bum_Latn), Bura-Pabir (bwr_Latn), Burak (bys_Latn), Bushi (buc_Latn), Bété, Daloa (bev_Latn), Bété, Guiberoua (bet_Latn), Cahungwarya (nat_Latn), Cakfem-Mushere (cky_Latn), Cebaara Senoufo (sef_Latn), Central Atlas Tamazight (tzm_Latn), Central-Eastern Niger Fulfulde (fuq_Latn), Cerma (cme_Latn), Chiduruma (dug_Latn), Chiga (cgg_Latn), Chokwe (cjk_Latn), Chumburung (ncu_Latn), Cicipu (awc_Latn), Cishingini (asg_Latn), Comorian, Ngazidja (zdj_Latn), Crioulo, Upper Guinea (pov_Latn), C’Lela (dri_Latn), Daba (dbq_Latn), Dadiya (dbd_Latn), Dagaare, Southern (dga_Latn), Dagbani (dag_Latn), Dan (dnj_Latn), Dan (dnj_Latn_LR), Dangaléat (daa_Latn), Dawro (dwr_Latn), Dazaga (dzg_Latn), Deg (mzw_Latn), Delo (ntr_Latn), Dendi (ddn_Latn), Denya (anv_Latn), Dghwede (dgh_Latn), Dida, Yocoboué (gud_Latn), Didinga (did_Latn), Dii (dur_Latn), Dikaka (cfa_Latn), Dinka (din_Latn), Dinka, Northeastern (dip_Latn), Ditammari (tbz_Latn), Dogon, Toro So (dts_Latn), Doyayo (dow_Latn), Duala (dua_Latn), Duya (ldb_Latn), Dyan (dya_Latn), Dyula (dyu_Latn), Dza (jen_Latn), Eastern Gurung, Latin (ggn_Latn), Ebira (igb_Latn), Ede Cabe (cbj_Latn), Ede Ica (ica_Latn), Ede Idaca (idd_Latn), Ede Ije (ijj_Latn), Efik (efi_Latn), Ejagham (etu_Latn), Ekajuk (eka_Latn), Ekpeye (ekp_Latn), Elip (ekm_Latn), Emai-Iuleha-Ora (ema_Latn), Embu (ebu_Latn), Engenni (enn_Latn), English (en_Latn), Esan (ish_Latn), Etkywan (ich_Latn), Etulo (utr_Latn), Ewe (ee_Latn), Ewondo (ewo_Latn), Ezaa (eza_Latn), Fang (fan_Latn), Fanti (fat_Latn), Fe’fe’ (fmp_Latn), Fon (fon_Latn), Foodo (fod_Latn), Frafra (gur_Latn), French (fr_Latn), Fulah (ff_Latn), Fulfulde, Adamawa (fub_Latn), Fulfulde, Borgu (fue_Latn), Fulfulde, Western Niger (fuh_Latn), Fuliiru (flr_Latn), Fur (fvr_Latn), Ga (gaa_Latn), Gamo (gmv_Latn), Ganda (lg_Latn), Gbari (gby_Latn), Gbaya (Sudan) (krs_Latn), Gbaya-Mbodomo (gmm_Latn), Gbe, Tofin (tfi_Latn), Gbe, Waci (wci_Latn), Gbe, Xwela (xwe_Latn), Gen (gej_Latn), German (de_Latn), Ghomala (bbj_Latn), Gikyode (acd_Latn), Godié (god_Latn), Goemai (ank_Latn), Gofa (gof_Latn), Gokana (gkn_Latn), Gonja (gjn_Latn), Goo (gov_Latn), Gor (gqr_Latn), Gourmanchéma (gux_Latn), Grebo (grb_Latn), Gude (gde_Latn), Gulay (gvl_Latn), Gumuz (guk_Latn), Gun (guw_Latn), Gungu (rub_Latn), Guro (goa_Latn), Gusii (guz_Latn), Gwak (jgk_Latn), Gyele (gyi_Latn), Hanga (hag_Latn), Harari (har_Latn), Hassaniyya (mey_Latn), Hausa (ha_Latn), Hdi (xed_Latn), Herero (hz_Latn), Hyam (jab_Latn), Ibani (iby_Latn), Ibibio (ibb_Latn), Idoma (idu_Latn), Ifè (ife_Latn), Igbo (ig_Latn), Igede (ige_Latn), Igo (ahl_Latn), Ijo, Southeast (ijs_Latn), Ik (ikx_Latn), Ika (ikk_Latn), Ikposo (kpo_Latn), Ikwere (ikw_Latn), Ikwo (iqw_Latn), Iten (etx_Latn), Ivbie North-Okpela-Arhe (atg_Latn), Izere (izr_Latn), Izii (izz_Latn), Jenaama Bozo (bze_Latn), Jibu (jib_Latn), Jju (kaj_Latn), Jola-Fonyi (dyo_Latn), Jola-Kasa (csk_Latn), Jukun Takum (jbu_Latn), Jur Modo (bex_Latn), Juǀʼhoan (ktz_Latn), Kaansa (gna_Latn), Kabalai (kvf_Latn), Kabba (ksp_Latn), Kabiyé (kbp_Latn), Kabuverdianu (kea_Latn), Kabyle (kab_Latn), Kako (kkj_Latn), Kalanga (kck_Latn), Kalenjin (kln_Latn), Kamba (kam_Latn), Kamuku (cdr_Latn), Kamwe (hig_Latn), Kanuri (kr_Latn), Kanuri, Central (knc_Latn), Kanuri, Manga (kby_Latn), Kaonde (kqn_Latn), Karaboro, Eastern (xrb_Latn), Karang (kzr_Latn), Karekare (kai_Latn), Kasem (xsm_Latn), Kasem (xsm_Latn_BF), Kenga (kyq_Latn), Kenyang (ken_Latn), Kibaku (ckl_Latn), Kikuyu (ki_Latn), Kim (kia_Latn), Kimbundu (kmb_Latn), Kimré (kqp_Latn), Kinyarwanda (rw_Latn), Kirike (okr_Latn), Kissi, Northern (kqs_Latn), Kita Maninkakan (mwk_Latn), Kituba (ktu_Latn), Koalib (kib_Latn), Kom (bkm_Latn), Koma (kmy_Latn), Kombe (nui_Latn), Kongo (kg_Latn), Konjo (koo_Latn), Konkomba (xon_Latn), Koonzime (ozm_Latn), Koro (kfo_Latn), Koro Wachi (bqv_Latn), Kouya (kyf_Latn), Koyra Chiini (khq_Latn), Koyraboro Senni (ses_Latn), Kpelle (kpe_Latn), Kpelle, Guinea (gkp_Latn), Krache (kye_Latn), Krio (kri_Latn), Krumen, Plapo (ktj_Latn), Krumen, Tepo (ted_Latn), Kuanyama (kj_Latn), Kukele (kez_Latn), Kulango, Bouna (nku_Latn), Kunama (kun_Latn), Kuo (xuo_Latn), Kuria (kuj_Latn), Kusaal (kus_Latn), Kutep (kub_Latn), Kutu (kdc_Latn), Kwanja (knp_Latn), Kwasio (nmg_Latn), Kwere (cwe_Latn), Lama (Togo) (las_Latn), Lamang (hia_Latn), Lamba (lam_Latn), Lamnso’ (lns_Latn), Langi (lag_Latn), Lango [Uganda] (laj_Latn), Lehar (cae_Latn), Lele (lln_Latn), Lendu (led_Latn), Lese (les_Latn), Ligbi (lig_Latn), Limba, West-Central (lia_Latn), Limbum (lmp_Latn), Lingala (ln_Latn), Lobala (loq_Latn), Lobi (lob_Latn), Logo (log_Latn), Lokaa (yaz_Latn), Loko (lok_Latn), Lomwe (ngl_Latn), Longuda (lnu_Latn), Lozi (loz_Latn), Luba-Katanga (lu_Latn), Luba-Lulua (lua_Latn), Lugbara (lgg_Latn), Luguru (ruf_Latn), Lukpa (dop_Latn), Lunda (lun_Latn), Luo (luo_Latn), Luvale (lue_Latn), Luwo (lwo_Latn), Luyia (luy_Latn), Lyélé (lee_Latn), Láá Láá Bwamu (bwj_Latn), Maasina Fulfulde (ffm_Latn), Machame (jmc_Latn), Mada (mda_Latn), Mafa (maf_Latn), Makaa (mcp_Latn), Makhuwa (vmw_Latn), Makhuwa-Meetto (mgh_Latn), Makonde (kde_Latn), Malagasy (mg_Latn), Malba Birifor (bfo_Latn), Mamara Senoufo (myk_Latn), Mambila, Cameroon (mcu_Latn), Mambila, Nigeria (mzk_Latn), Mampruli (maw_Latn), Mandingo (man_Latn), Mandinka (mnk_Latn), Mandjak (mfv_Latn), Mangbetu (mdj_Latn), Mango (mge_Latn), Maninka, Sankaran (msc_Latn), Maninkakan, Eastern (emk_Latn), Mankanya (knf_Latn), Mano (mev_Latn), Manyika (mxc_Latn), Maore Comorian, Latin (swb_Latn), Masaaba (myx_Latn), Masai (mas_Latn), Masalit (mls_Latn), Masana (mcn_Latn), Ma’di (mhi_Latn), Mbe (mfo_Latn), Mbelime (mql_Latn), Mbembe, Cross River (mfn_Latn), Mbere (mdt_Latn), Mbo (mbo_Latn), Mbuko (mqb_Latn), Mbula-Bwazza (mbu_Latn), Mbunga (mgy_Latn), Medumba (byv_Latn), Mendankwe-Nkwen (mfd_Latn), Mende (men_Latn), Merey (meq_Latn), Meru (mer_Latn), Metaʼ (mgo_Latn), Me’en (mym_Latn), Mfumte (nfu_Latn), Mina (hna_Latn), Miyobe (soy_Latn), Mmaala (mmu_Latn), Moba (mfq_Latn), Mokole (mkl_Latn), Mongo (lol_Latn), Morisyen (mfe_Latn), Moro (mor_Latn), Morokodo (mgc_Latn), Mossi (mos_Latn), Mumuye (mzm_Latn), Mundang (mua_Latn), Mundani (mnf_Latn), Murle (mur_Latn), Muyang (muy_Latn), Mwaghavul (sur_Latn), Mwan (moa_Latn), Mwani (wmw_Latn), Ménik (tnr_Latn), Mündü (muh_Latn), Nafaanra (nfr_Latn), Nama (naq_Latn), Nara (nrb_Latn), Nateni (ntm_Latn), Nawdm (nmz_Latn), Nawuri (naw_Latn), Ndamba (ndj_Latn), Ndau (ndc_Latn), Ndogo (ndz_Latn), Ndonga (ng_Latn), Ndrulo (dno_Latn), Ndut (ndv_Latn), Ngambay (sba_Latn), Ngangam (gng_Latn), Ngas (anc_Latn), Ngbaka (nga_Latn), Ngbandi, Northern (ngb_Latn), Ngiemboon (nnh_Latn), Ngindo (nnq_Latn), Ngiti (niy_Latn), Ngomba (jgo_Latn), Ngulu (ngp_Latn), Nigerian Fulfulde (fuv_Latn), Nigerian Pidgin (pcm_Latn), Ninzo (nin_Latn), Nkonya (nko_Latn), Nomaande (lem_Latn), Noon (snf_Latn), Noone (nhu_Latn), North Ndebele (nd_Latn), Northern Bobo Madaré (bbo_Latn), Northern Dagara (dgi_Latn), Northern Sotho (nso_Latn), Ntcham (bud_Latn), Nuer (nus_Latn), Nugunu (yas_Latn), Nuni, Northern (nuv_Latn), Nupe-Nupe-Tako (nup_Latn), Nyabwa (nwb_Latn), Nyamwezi (nym_Latn), Nyangbo (nyb_Latn), Nyanja (ny_Latn), Nyankole (nyn_Latn), Nyasa Tonga (tog_Latn), Nyemba (nba_Latn), Nyoro (nyo_Latn), Nzakara (nzk_Latn), Nzima (nzi_Latn), Nǁng (ngh_Latn), Obolo (ann_Latn), Ogbah (ogc_Latn), Okiek (oki_Latn), Oromo (om_Latn), Otuho (lot_Latn), Paasaal (sig_Latn), Pana (Central African Republic) (pnz_Latn), Pangu (png_Latn), Parkwa (pbi_Latn), Pero (pip_Latn), Phuie (pug_Latn), Pogolo (poy_Latn), Pokomo (pkb_Latn), Portuguese (pt_Latn), Pulaar (fuc_Latn), Pular (fuf_Latn), Punu (puu_Latn), Pyam (pym_Latn), Pökoot (pko_Latn), Rendille (rel_Latn), Reshe (res_Latn), Riffian (Latin) (rif_Latn), Rigwe (iri_Latn), Rombo (rof_Latn), Ron (cla_Latn), Ronga (rng_Latn), Rundi (rn_Latn), Rwa (rwk_Latn), Réunion Creole French (rcf_Latn), Saafi-Saafi (sav_Latn), Safaliba (saf_Latn), Saho (ssy_Latn), Samburu (saq_Latn), Sandawe (sad_Latn), Sango (sg_Latn), Sangu (sbp_Latn), Sar (mwm_Latn), Saxwe Gbe (sxw_Latn), Seki (syi_Latn), Sekpele (lip_Latn), Selee (snw_Latn), Sena (seh_Latn), Serer (srr_Latn), Seselwa Creole French (crs_Latn), Shambala (ksb_Latn), Sheko (she_Latn), Shilluk (shk_Latn), Shona (sn_Latn), Sidamo (sid_Latn), Sisaala, Tumulung (sil_Latn), Sissala (sld_Latn), Siwu (akp_Latn), Soga (xog_Latn), Sokoro (sok_Latn), Somali (so_Latn), Soninke (snk_Latn), South Central Banda (lnl_Latn), South Ndebele (nr_Latn), Southern Bobo Madaré (bwq_Latn), Southern Kisi (kss_Latn), Southern Nuni (nnw_Latn), Southern Samo (sbd_Latn), Southern Sotho (st_Latn), Spanish (es_Latn), Suba (sxb_Latn), Sudanese Arabic (apd_Latn), Sukuma (suk_Latn), Suri, Tirmaga-Chai (suq_Latn), Susu (sus_Latn), Swahili (sw_Latn), Swahili, Congo (swc_Latn), Swati (ss_Latn), Syenara Senoufo (shz_Latn), Sãotomense (cri_Latn), Sénoufo, Djimini (dyi_Latn), Sénoufo, Supyire (spp_Latn), Tachelhit (Latin) (shi_Latn), Tafi (tcd_Latn), Taita (dav_Latn), Takwane (tke_Latn), Tal (tal_Latn), Talinga-Bwisi (tlj_Latn), Tamashek (tmh_Latn), Tamasheq, Latin (taq_Latn), Tampulma (tpm_Latn), Tangale (tan_Latn), Tarok (yer_Latn), Tasawaq (twq_Latn), Tawallammat Tamajaq (ttq_Latn), Tedaga (tuq_Latn), Tem (kdh_Latn), Tera (ttr_Latn), Teso (teo_Latn), Tigon Mbembe (nza_Latn), Tikar (tik_Latn), Timne (tem_Latn), Tiv (tiv_Latn), Tiéyaxo Bozo (boz_Latn), Toma (tod_Latn), Tomo Kan Dogon (dtm_Latn), Tonga (toi_Latn), Tooro (ttj_Latn), Toposa (toq_Latn), Toura (neb_Latn), Toussian, Southern (wib_Latn), Tsikimba (kdl_Latn), Tsishingini (tsw_Latn), Tsonga (ts_Latn), Tsuvadi (tvd_Latn), Tswana (tn_Latn), Tula (tul_Latn), Tumbuka (tum_Latn), Tunen (tvu_Latn), Tunisian Darija (aeb_Latn), Turka (tuz_Latn), Tuwuli (bov_Latn), Tyap (kcg_Latn), Téén (lor_Latn), Uduk (udu_Latn), Umbundu (umb_Latn), Vagla (vag_Latn), Vai (Latin) (vai_Latn), Venda (ve_Latn), Vengo (bav_Latn), Vidunda (vid_Latn), Vunjo (vun_Latn), Vute (vut_Latn), Waama (wwa_Latn), Waja (wja_Latn), Wamey (cou_Latn), Wan (wan_Latn), Wandala (mfi_Latn), Warji (wji_Latn), Winyé (kst_Latn), Wolaytta (wal_Latn), Wolof (wo_Latn), Wè Northern (wob_Latn), Xaasongaxango (kao_Latn), Xhosa (xh_Latn), Yala (yba_Latn), Yalunka (yal_Latn), Yamba (yam_Latn), Yambeta (yat_Latn), Yangben (yav_Latn), Yao (yao_Latn), Yaouré (yre_Latn), Yasa (yko_Latn), Yemba (ybb_Latn), Yom (pil_Latn), Yoruba (yo_Latn), Zaghawa (zag_Latn), Zande (zne_Latn), Zarma (dje_Latn), Zayse (zay_Latn), Zigula (ziw_Latn), Zulgo-Gemzek (gnd_Latn), Zulu (zu_Latn), gevové (buw_Latn), ut-Hun (uth_Latn), ut-Ma’in (gel_Latn)`

The resulting glyphset can be found here: [GF_Latin_African.nam](/Lib/glyphsets/definitions/nam/GF_Latin_African.nam)


## GF Arabic Core

GF_Arabic_Core is **statically** defined as:

* Script: Arabic
* Codepoints defined in [GF_Arabic_Core.stub.nam](/GF_glyphsets/Arabic/definitions/GF_Arabic_Core.stub.nam)
* List of languages: `Arabic (ar_Arab), Persian (fa_Arab), Urdu (ur_Arab)`

The resulting glyphset can be found here: [GF_Arabic_Core.nam](/Lib/glyphsets/definitions/nam/GF_Arabic_Core.nam)


## GF Arabic Plus

GF_Arabic_Plus is **statically** defined as:

* Script: Arabic
* List of languages: `Central Kurdish (ckb_Arab), Malay (Arabic) (ms_Arab), Pashto (ps_Arab), Sindhi (sd_Arab), Uyghur (ug_Arab)`

The resulting glyphset can be found here: [GF_Arabic_Plus.nam](/Lib/glyphsets/definitions/nam/GF_Arabic_Plus.nam)

